@@ -1,20 +1,26 @@
-intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output", folder=getwd(), config) {
+intsvy.ben.pv <- function(pvnames, by, cutoff, data, atlevel = FALSE, 
+                          export=FALSE, name= "output", folder=getwd(), config) {
 
     if (missing(cutoff)) {
     cutoff = config$parameters$cutoffs
     }
-  pv.ben.input <- function(pvlabel, data, cutoff, config) {
+  pv.ben.input <- function(pvnames, data, cutoff, config) {
     
     #  JK
     if (config$parameters$weights == "JK") {
       # jack knife
       # in PIRLS / TIMSS
-      pvname <- paste(pvlabel, "0", 1:config$parameters$PVreps, sep='')
-
+      
+      if (isTRUE(atlevel)) {
+        stop("Not implemented yet")
+      }
+        
+      pvnames <- grep(pvnames, names(data), value = TRUE)
+      
       # data is empty
-      if (sum(is.na((data[[pvname[1]]])))==length(data[[pvname[1]]])) {
+      if (sum(is.na((data[[pvnames[1]]])))==length(data[[pvnames[1]]])) {
         result <- data.frame(NA, "Freq"=0, "Percentage"=NA, "Std.err."= NA)  
-        names(result)[1] <- pvname[1] 
+        names(result)[1] <- pvnames[1] 
         return(result)
       }
       
@@ -26,10 +32,10 @@ intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output
       
       if (isTRUE(config$parameters$varpv1)) {
       tabpv1 <- sapply(1:length(cutoff), function(z) sapply(1:ncol(R.wt), function(x) 
-        100*weighted.mean(data[[pvname[1]]]>=cutoff[z], w = R.wt[,x])))
+        100*weighted.mean(data[[pvnames[1]]]>=cutoff[z], w = R.wt[,x])))
             
          # Total weighted %s PV1-5 
-      tabpv <- sapply(1:length(cutoff), function(z) sapply(pvname, function(x) 
+      tabpv <- sapply(1:length(cutoff), function(z) sapply(pvnames, function(x) 
         100*weighted.mean(data[[x]]>=cutoff[z], w=data[[config$variables$weight]], na.rm=TRUE)))
       
       # Sampling error within (PV1), between PV error, and total (se)
@@ -54,16 +60,16 @@ intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output
         
         R.wt <- cbind(R.wt, R.wt2)  
         
-        tabpv1 <-  lapply(1:config$parameters$PVreps, function(m) sapply(1:length(cutoff), function(z) 
+        tabpv1 <-  lapply(1:length(pvnames), function(m) sapply(1:length(cutoff), function(z) 
           sapply(1:ncol(R.wt), function(x)
-          100*weighted.mean(data[[pvname[m]]]>=cutoff[z], w = R.wt[,x]))))
+          100*weighted.mean(data[[pvnames[m]]]>=cutoff[z], w = R.wt[,x]))))
 
         # Total weighted %s PV1-5 
-        tabpv <- sapply(1:length(cutoff), function(z) sapply(pvname, function(x) 
+        tabpv <- sapply(1:length(cutoff), function(z) sapply(pvnames, function(x) 
           100*weighted.mean(data[[x]]>=cutoff[z], w=data[[config$variables$weight]], na.rm=TRUE)))
         
         # Sampling error within (PV1), between PV error, and total (se)
-          tabpvw <- apply(do.call(rbind, lapply(1:config$parameters$PVreps, function(m) 
+          tabpvw <- apply(do.call(rbind, lapply(1:length(pvnames), function(m) 
           sapply(1:length(cutoff), function(y) 
           sum(sapply(1:ncol(R.wt), function(x) (tabpv1[[m]][x,y]-tabpv[m,y])^2))/2))), 2, mean)
         
@@ -80,12 +86,17 @@ intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output
         
       }
     }
+    
     # BRR 
     if (config$parameters$weights == "BRR") {
       # balanced repeated replication
       # Replicate weighted %s (sampling error)
       # in PISA / PIAAC
-      pvnames <- paste("PV", 1:config$parameters$PVreps, pvlabel, sep="")
+     
+      pvnames <- paste0(pvnames, ".*PV[0-9]|PV[0-9].*", pvnames)
+      pvnames <- grep(pvnames, names(data), value = TRUE)
+      weights <- grep(paste0("^", config$variables$weightBRR , ".*[0-9]+$"), 
+                      names(data), value = TRUE)
       
       # data is empty
       if (sum(is.na((data[[pvnames[1]]])))==length(data[[pvnames[1]]])) {
@@ -94,6 +105,8 @@ intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output
         return(result)
       }
 
+      if (isTRUE(atlevel)) {
+        
       # First level indicator (1/0) for 5 PVs
       level1 <- lapply(pvnames, function(x) ifelse(data[[x]] <= cutoff[1], 1, 0))
       
@@ -111,7 +124,7 @@ intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output
       tabpvrp <- lapply(1:length(pvnames), function(x) 
                     sapply(1:config$parameters$BRRreps, function(i) 
                         100*apply(level.data[[x]], 2, weighted.mean, 
-                            w = data[[paste(config$variables$weightBRR, i , sep="")]], na.rm= TRUE)))
+                            w = data[[weights[i]]], na.rm= TRUE)))
       
       # Total percentages for pvs
       tabpvt <- sapply(1:length(pvnames), function(x) 
@@ -132,11 +145,53 @@ intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output
                ", ", cutoff[2:length(cutoff)], "]"), paste0("> ", cutoff[length(cutoff)])),
                "Percentage"=round(tabtot, 2), "Std. err."= round(tabse,2), check.names=F)
       return(result)
-    } 
+      } 
+      
+    if (isFALSE(atlevel)) {
+      
+      # variation across pvs and weights
+      tabpvrp <-  lapply(1:length(pvnames), function(m) sapply(1:length(cutoff), function(z) 
+        sapply(1:config$parameters$BRRreps, function(i)
+          100*weighted.mean(data[[pvnames[m]]]>=cutoff[z], 
+                            w = data[[weights[i]]], na.rm=TRUE))))      
+      
+      
+      # PV variation across total weight
+      tabpvt <- sapply(1:length(cutoff), function(z) sapply(pvnames, function(x) 
+        100*weighted.mean(data[[x]]>=cutoff[z], 
+                          w=data[[config$variables$weightFinal]], na.rm=TRUE)))
+      
+      
+      # Mean of means (the one is reported)
+      tabtot <- apply(tabpvt, 2, mean)
+      
+      
+      # Sampling error, between PV error, and total (se)
+      varw <- apply(sapply(1:length(cutoff), 
+                      function(cut) 0.05*apply(sapply(1:length(pvnames),
+                      function(pv) sapply(1:config$parameters$BRRreps, function(w) 
+                       (tabpvrp[[pv]][w, cut] - tabpvt[pv , cut])^2)), 2, sum)), 2, mean)
+      
+      varb <- (1/(length(pvnames)-1))*apply(sapply(1:length(cutoff), 
+              function(cut) sapply(1:length(pvnames), function(pv) 
+              (tabpvt[pv, cut]-tabtot[cut])^2)), 2, sum)
+      
+      tabse <-(varw+(1+1/length(pvnames))*varb)^(1/2)
+      
+      # Result
+      
+      result <- data.frame("Benchmark"=paste(rep("At or above", length(cutoff)), cutoff), 
+                           "Percentage"=round(tabtot,2), 
+                           "Std. err."= round(tabse,2), check.names=F)
+      
+      return(result)
+      
+      }
+    }
+      
     if (config$parameters$weights == "mixed_piaac") {
       # mixed design, different for different countries
       # PIAAC
-      pvnames <- paste("PV", pvlabel, 1:config$parameters$PVreps, sep="")
 
       # data is empty
       if (sum(is.na((data[[pvnames[1]]])))==length(data[[pvnames[1]]])) {
@@ -160,17 +215,17 @@ intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output
       levell <- lapply(pvnames, function(x) ifelse(data[[x]] > cutoff[length(cutoff)], 1, 0))
       
       # Recoded data for standard analysis
-      level.data <- lapply(1:config$parameters$PVreps, function(x) 
+      level.data <- lapply(1:length(pvnames), function(x) 
                         cbind(level1[[x]], level.int[[x]], levell[[x]]))
       
       # Percentages for replicates and pvs
-      tabpvrp <- lapply(1:config$parameters$PVreps, function(x) 
+      tabpvrp <- lapply(1:length(pvnames), function(x) 
                         sapply(1:config$parameters$BRRreps, function(i) 
                                 100*apply(level.data[[x]], 2, weighted.mean, 
                                        w= data[[paste(config$variables$weightBRR, i , sep="")]], na.rm= TRUE)))
       
       # Total percentages for pvs
-      tabpvt <- sapply(1:config$parameters$PVreps, function(x) 
+      tabpvt <- sapply(1:length(pvnames), function(x) 
                       100*apply(level.data[[x]], 2, weighted.mean, 
                              w= data[[config$variables$weightFinal]], na.rm= TRUE))
       
@@ -182,12 +237,12 @@ intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output
       cc <- piaacReplicationScheme[cntName,"c"]
       if (is.na(cc)) cc <- 1
       
-      varw <- apply(sapply(1:config$parameters$PVreps, function(x) 
+      varw <- apply(sapply(1:length(pvnames), function(x) 
                   cc*apply(sapply(1:config$parameters$BRRreps, function(i) 
                         (tabpvrp[[x]][, i] - tabpvt[ , x])^2), 1, sum)), 1, mean)
-      varb <- (1/(config$parameters$PVreps-1))*apply(sapply(1:config$parameters$PVreps, 
+      varb <- (1/(length(pvnames)-1))*apply(sapply(1:length(pvnames), 
                                           function(x) (tabpvt[, x]-tabtot)^2), 1, sum)
-      tabse <-(varw+(1+1/config$parameters$PVreps)*varb)^(1/2)
+      tabse <-(varw+(1+1/length(pvnames))*varb)^(1/2)
       
       # Result
       result <- data.frame("Benchmarks"= c(paste("Below/equal to", cutoff[1]), 
@@ -201,12 +256,12 @@ intsvy.ben.pv <- function(pvlabel, by, cutoff, data, export=FALSE, name= "output
   
   # If by not supplied, calculate for complete sample    
   if (missing(by)) { 
-    output <- pv.ben.input(pvlabel=pvlabel, cutoff=cutoff, data=data, config=config)
+    output <- pv.ben.input(pvnames=pvnames, cutoff=cutoff, data=data, config=config)
   } else {
     for (i in by) {
       data[[c(i)]] <- as.factor(data[[c(i)]])
     }
-    output <- ddply(data, by, function(x) pv.ben.input(pvlabel=pvlabel, cutoff=cutoff, data=x, config=config))
+    output <- ddply(data, by, function(x) pv.ben.input(pvnames=pvnames, cutoff=cutoff, data=x, config=config))
   }
   if (export)  {
     write.csv(output, file=file.path(folder, paste(name, ".csv", sep="")))
